package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: Apr 2, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Report struct {
OCRAvailable bool `json:"ocr_available"`
OCRPreprocessingAvailable bool `json:"ocr_preprocessing_available"`
Tesseract Tool `json:"tesseract"`
ImageMagickConvert Tool `json:"imagemagick_convert"`
}
type Tool struct {
Available bool `json:"available"`
Path string `json:"path,omitempty"`
Version string `json:"version,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.