package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: Apr 2, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Verdict struct {
Type string `json:"type"`
Confidence float64 `json:"confidence"`
Signals []string `json:"signals,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.